<?php 
/*
Plugin Name: Euro 2012 Predictor
Plugin URI: http://www.ianhaycox.com/euro2012
Description: Euro 2012 Predictor - Guess the outcome of the UEFA Euro 2012 football/soccer matches, aka Fantasy Football
Version: 0.3
SVN Version: $Id$
Author: Ian Haycox
Author URI: http://www.ianhaycox.com
Copyright Ian Haycox, 2012 (email : ian.haycox@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
 * @package Euro2012
 * @version $Id$
 * @author ian
 * Copyright Ian Haycox, 2012
 *
 */

define('EURO_TD', 'euro-2012-predictor');  // Text domain & plugin dir
load_plugin_textdomain(EURO_TD, false, 'euro-2012-predictor/lang');

class Euro2012 {
	
	const VERSION = '0.3';

	var $prefix = 'euro2012_';

	/**
	 * error handling
	 *
	 * @var boolean
	 */
	private $error = false;
	
	/**
	 * message
	 *
	 * @var string
	 */
	private $message = null;
	
	function __construct() {
	}
		
	function enqueue_scripts() {
		wp_enqueue_script($this->prefix . 'js', WP_PLUGIN_URL . '/' . EURO_TD.'/js/user.js', array( 'jquery' ));
		wp_localize_script($this->prefix.'js', 'Euro2012PredictorAjax', 
				array(  'url' => plugins_url('', dirname(__FILE__)),
						'blogUrl' => admin_url( 'admin-ajax.php' ),
						'prefix' => $this->prefix) );
		
		wp_enqueue_style($this->prefix.'style', plugins_url('/css/style.css', __FILE__));
	}
	
	/**
	 * Initialize the plugin widgets
	 */
	function widgets_init() {
		/*
		 * For the results table
		 */
		require_once(dirname(__FILE__).'/widgets.class.php');
		register_widget('Euro2012PredictorWidget');
		register_widget('Euro2012PredictorUserWidget');
	}
	
	function wp_footer() {
		if (get_option($this->prefix.'promo_link', 1)) {
			echo '<p class="euro2012_promo_link"><a target="_blank" href="http://www.ianhaycox.com/">Euro 2012 Predictor by Ian Haycox</a></p>';
		}
	}
	
	/*
	 * Process shortcode [euro2012]
	 * 
	 */
	function shortcode($atts) {
		extract(shortcode_atts(array(
			'predict' => 1,
			'ranking' => 0,
			'tables' => 0,		// Show group tables
			'scores' => 0,		// All users predictions by match id
			'stage' => 0,		// group id - zero = all
			'show_results' => 1,// show match results below group tables
			'results' => 0,		// match results
			'knockout' => 0,	// Knockout stage results
			'user' => 0,		// Display current users predictions
			'limit' => 999999,	// Limit ranking and prediction scores
			'highlight' => '',	// CSS style to apply to current user in rankings
			'show_total' => 0,	// Display total in user predictions
			'group' => false,	// Show only group stage matches
			'kickoff' => false,	// Order matches by kickoff time
			'predict_penalties' => true // Users can predict penalty goals.
		), $atts));

		$output = '';
		
		if (!is_numeric($stage)) {
			$stage = 0;
		}
		
		if (!is_numeric($limit)) {
			$limit = 999999;
		}
		
		if ($ranking) {
			require_once(dirname(__FILE__).'/reports.class.php');
			$r = new Euro2012Report();
			$output =  $r->user_ranking($limit, false, $highlight);
			return $output;
		}
		
		if ($tables) {
			require_once(dirname(__FILE__).'/reports.class.php');
			$r = new Euro2012Report();
			$output =  $r->group_tables($stage, $show_results);
			return $output;
		}
		
		if ($scores) {
			require_once(dirname(__FILE__).'/reports.class.php');
			$r = new Euro2012Report();
			$output =  $r->user_scores($scores, $limit, -1, $highlight);
			return $output;
		}
		
		if ($results) {
			require_once(dirname(__FILE__).'/reports.class.php');
			$r = new Euro2012Report();
			$output =  $r->results($stage);
			return $output;
		}
		
		if ($knockout) {
			require_once(dirname(__FILE__).'/reports.class.php');
			$r = new Euro2012Report();
			$output =  $r->knockout();
			return $output;
		}
		
		if ($user || $show_total) {
			require_once(dirname(__FILE__).'/reports.class.php');
			$r = new Euro2012Report();
			$output =  $r->user_predictions($user, $show_total, $show_results);
			return $output;
		}
		
		if ($predict) {
			require_once(dirname(__FILE__).'/predict.class.php');
			$p = new Euro2012Predict();
			$output =  $p->prediction_form($stage, $limit, $group, $kickoff, $predict_penalties);
			return $output;
		}
		
	}
	
	function debug($var, $echo = true) {
		$output = "<pre>";
		$output .= print_r($var, true);
		$output .= "</pre>";
		if ($echo) echo $output;
		return $output;
	}
	
	/**
	 * Clean the input string of dangerous input.
	 * @param $str input string
	 * @return cleaned string.
	 */
	function clean($str) {
		$str = strip_tags($str);
		return @trim(htmlspecialchars($str, ENT_QUOTES));
	}
	
	/**
	 * Reverse clean() after getting from DB
	 * @param $str input string
	 * @return cleaned string.
	 */
	function unclean($str) {
		return stripslashes($str);
	}
	
	function flag($country) {
		$class = ($country != 'xxx' ? $this->prefix.'flag' : '');
		return '<img alt="" class="'.$class.'" src="'.WP_PLUGIN_URL.'/'.EURO_TD.'/images/'.strtolower($country).'.png" />';
	}
	
	/**
	 * set message
	 *
	 * @param string $message
	 * @param boolean $error triggers error message if true
	 * @return none
	 */
	function setMessage( $message, $error = false )
	{
		$type = 'success';
		if ( $error ) {
			$this->error = true;
			$type = 'error';
		}
		$this->message[$type] = $message;
	}
	
	
	/**
	 * return message
	 *
	 * @param none
	 * @return string
	 */
	function getMessage()
	{
		if (is_null($this->message) || (empty($this->message))) return false;
		
		if ( $this->error )
			return $this->message['error'];
		else
			return $this->message['success'];
	}
	
	
	/**
	 * print formatted message
	 *
	 * @param none
	 * @return string
	 */
	function printMessage($echo = true)
	{
		if ($this->getMessage() === false)  return '';
		
		$str = '';
		
		if ( $this->error )
			$str = "<div class='{$this->prefix}notice message error'><p>".$this->getMessage()."</p></div>";
		else
			$str = "<div class='{$this->prefix}notice message updated fade'><p><strong>".$this->getMessage()."</strong></p></div>";
		$this->message = null;
		
		if (!$echo) return $str;
		echo $str;
	}
	
	/*
	 * Check for zero or positive integer 
	 * TODO allow leading zeros !
	 */
	function isint($i) {
		return ((string)$i === (string)(int)$i && (int)$i >= 0);
	}
	
	/*
	 * Return an href
	 */
	function mklink($str, $url, $title) {
		$link = $str;
		if (!empty($url)) {
			$link = '<a href="'.$url.'" title="'.$title.'" alt="'.$title.'">'.$str.'</a>';
		} else {
			$link = '<span title="'.$title.'">'.$str.'</span>';
		}
		return $link;
	}
	
	function format_date($mysql_date) {
		return mysql2date(get_option('date_format') . ' ' . get_option('time_format'), $mysql_date);
	}
	
}

function euro2012_uninstall() {
	global $wpdb;
	
	$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}euro2012_stage");
	$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}euro2012_team");
	$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}euro2012_venue");
	$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}euro2012_match");
	$wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}euro2012_prediction");
	
	delete_option( 'euro2012_db_version' );
	delete_option( 'euro2012_promo_link' );
	delete_option( 'euro2012_group_stats' );
	delete_option( 'euro2012_scoring' );
	delete_option( 'euro2012_countdown_format' );
	delete_option( 'euro2012_browser_locale' );
	
	$roles = array("subscriber", "contributor", "author", "editor", "administrator");
	foreach ($roles as $role) {
		$arole = get_role($role);
		$arole->remove_cap('euro2012_manager');
	}
}
	


$euro2012 = new Euro2012();

add_shortcode(EURO_TD, array(&$euro2012, 'shortcode'));

add_action('wp_enqueue_scripts', array(&$euro2012, 'enqueue_scripts'));
add_action('widgets_init', array(&$euro2012, 'widgets_init'));
add_action('wp_footer', array(&$euro2012, 'wp_footer'));

require_once(dirname(__FILE__).'/predict.class.php');
$euro2012p = new Euro2012Predict();
add_action('wp_ajax_euro2012_ajax', array(&$euro2012p,'ajax'));


if (is_admin()) {

	require_once(dirname(__FILE__).'/admin/admin.class.php');
	require_once(dirname(__FILE__).'/admin/teams.class.php');
	require_once(dirname(__FILE__).'/admin/venues.class.php');
	require_once(dirname(__FILE__).'/admin/stages.class.php');
	require_once(dirname(__FILE__).'/admin/matches.class.php');
	require_once(dirname(__FILE__).'/admin/predictions.class.php');
	require_once(dirname(__FILE__).'/admin/scoring.class.php');
	require_once(dirname(__FILE__).'/admin/overview.class.php');
	require_once(dirname(__FILE__).'/admin/results.class.php');
	require_once(dirname(__FILE__).'/reports.class.php');

	
	$euro2012admin = new Euro2012Admin();

	// Activation function
	register_activation_hook(__FILE__, array(&$euro2012admin, 'activate'));
	register_deactivation_hook(__FILE__, array(&$euro2012admin, 'deactivate'));

	// Register a uninstall hook to automatically remove all tables & option
	if ( function_exists('register_uninstall_hook') )
		register_uninstall_hook( __FILE__ , 'euro2012_uninstall' );

	add_action('admin_menu', array(&$euro2012admin, 'admin_menu'));
	add_action('admin_enqueue_scripts', array(&$euro2012admin, 'admin_enqueue_scripts'));
	add_action('admin_print_styles', array(&$euro2012admin, 'admin_print_styles'));
	add_action('admin_init', array(&$euro2012admin, 'admin_init'));
}


?>